pub struct TreeSitterRegistry {
pub extension_map: TreeSitterExtensionMap,
pub languages: TreeSitterConfigMap,
}Expand description
Combined Tree-sitter registry used by the UI layer and FFI boundary.
Fields
extension_map: TreeSitterExtensionMapMapping from extension → language id.
languages: TreeSitterConfigMapMapping from language id → file-based config.
Implementations
Sourceimpl TreeSitterRegistry
impl TreeSitterRegistry
Sourcepub fn from_json_str(json: &str) -> Result<Self, TreeSitterRegistryError>
pub fn from_json_str(json: &str) -> Result<Self, TreeSitterRegistryError>
Parse a schema-versioned Tree-sitter registry JSON string.
The registry supports:
- absolute paths
- or relative paths resolved against
root_dir
Sourcepub fn language_id_for_path<'a>(&'a self, path: &Path) -> Option<&'a str>
pub fn language_id_for_path<'a>(&'a self, path: &Path) -> Option<&'a str>
Return the configured language id for a file path, based on its extension.
Sourcepub fn scan_language_configs(
root_dir: &Path,
) -> Result<TreeSitterConfigMap, TreeSitterRegistryError>
pub fn scan_language_configs( root_dir: &Path, ) -> Result<TreeSitterConfigMap, TreeSitterRegistryError>
Scan a treesitter/ root directory and return a language_id -> config map.
This is useful for hosts that follow the conventional on-disk layout:
treesitter/
rust/
language.wasm
highlights.scmTrait Implementations
Sourceimpl Clone for TreeSitterRegistry
impl Clone for TreeSitterRegistry
Sourcefn clone(&self) -> TreeSitterRegistry
fn clone(&self) -> TreeSitterRegistry
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TreeSitterRegistry
impl Debug for TreeSitterRegistry
Sourceimpl Default for TreeSitterRegistry
impl Default for TreeSitterRegistry
Sourcefn default() -> TreeSitterRegistry
fn default() -> TreeSitterRegistry
Returns the “default value” for a type. Read more
impl Eq for TreeSitterRegistry
Sourceimpl PartialEq for TreeSitterRegistry
impl PartialEq for TreeSitterRegistry
Sourcefn eq(&self, other: &TreeSitterRegistry) -> bool
fn eq(&self, other: &TreeSitterRegistry) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for TreeSitterRegistry