editor-core-treesitter - Tree-sitter integration for editor-core.
This crate provides an offline incremental parsing pipeline that can produce:
- highlight intervals (a style layer)
- fold regions (derived folding)
Output is expressed as editor_core::ProcessingEdit values, so it composes with other derived
state producers like LSP or .sublime-syntax.
Structs
- Tree
Sitter Config - File-based Tree-sitter configuration for one language.
- Tree
Sitter Indenter - A small Tree-sitter powered indenter driven by an
indents.scmquery. - Tree
Sitter Indenter Config - Configuration for
TreeSitterIndenter. - Tree
Sitter Processor - An incremental Tree-sitter based document processor.
- Tree
Sitter Processor Config - Configuration for
TreeSitterProcessor. - Tree
Sitter Registry - Combined Tree-sitter registry used by the UI layer and FFI boundary.
Enums
- Tree
Sitter Error - Errors produced by
TreeSitterProcessor. - Tree
Sitter Language - Language source for a Tree-sitter processor.
- Tree
Sitter Load Error - Errors produced when loading Tree-sitter WASM and query files from disk.
- Tree
Sitter Registry Error - Errors produced when parsing/validating a Tree-sitter registry.
- Tree
Sitter Update Mode - How the processor updated its parse tree for the last
process()call.
Functions
- load_
indenter_ config_ from_ config - Load a
TreeSitterIndenterConfigfrom a file-basedTreeSitterConfig, if available. - load_
processor_ config_ from_ config - Load a
TreeSitterProcessorConfigfrom a file-basedTreeSitterConfig.
Type Aliases
- Tree
Sitter Config Map - Mapping from Tree-sitter
language_id(e.g."rust") to its on-disk configuration. - Tree
Sitter Extension Map - Mapping from file extension (without
.) to Tree-sitterlanguage_id.