pub struct TreeSitterProcessor { /* private fields */ }Expand description
An incremental Tree-sitter based document processor.
This processor tracks a parse tree and updates it based on TextDelta edits when available.
It then produces highlighting and folding edits in editor-core’s derived-state format.
Implementations
Sourceimpl TreeSitterProcessor
impl TreeSitterProcessor
Sourcepub fn new(config: TreeSitterProcessorConfig) -> Result<Self, TreeSitterError>
pub fn new(config: TreeSitterProcessorConfig) -> Result<Self, TreeSitterError>
Create a new processor from the given config.
Sourcepub fn last_update_mode(&self) -> TreeSitterUpdateMode
pub fn last_update_mode(&self) -> TreeSitterUpdateMode
Get the last update mode (useful for tests and instrumentation).